@@ -1,4 +1,4 @@
-/* $Id: udpkg.c 20745 2004-09-03 20:12:46Z joeyh $ */
+/* $Id: udpkg.c 28435 2005-06-15 21:13:27Z joeyh $ */
 #include "udpkg.h"
 
 #include <errno.h>
@@ -121,7 +121,7 @@ static int dpkg_dounpack(struct package_t *pkg)
 	int r = 0;
 	char *cwd;
 	char buf[1024], buf2[1024];
-	int i;
+	unsigned int i;
 	char *adminscripts[] = { "prerm", "postrm", "preinst", "postinst",
 	                         "conffiles", "md5sums", "shlibs", 
 				 "templates", "menutest", "isinstallable",
@@ -414,6 +414,7 @@ static int dpkg_remove(struct package_t *pkgs)
 #else
 	FPRINTF(stderr, "udpkg: No support for -r.\n");
 	return 1;
+	pkgs = 0; /* avoid -W warning */
 #endif
 }
 
